%global base_name woodstox

Name:           woodstox-core
Summary:        High-performance XML processor
Version:        6.2.3
Release:        %mkrel 1
Group:          Development/Java
License:        ASL 2.0 or LGPLv2+ or BSD

URL:            https://github.com/FasterXML/woodstox
Source0:        %{url}/archive/%{name}-%{version}.tar.gz

# Port to latest OSGi APIs
Patch0:         0001-Allow-building-against-OSGi-APIs-newer-than-R4.patch
# Drop requirements on defunct optional dependencies: msv and relaxng
Patch1:         0002-Patch-out-optional-support-for-msv-and-relax-schema-.patch

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  mvn(com.fasterxml:oss-parent:pom:)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-shade-plugin)
BuildRequires:  mvn(org.codehaus.woodstox:stax2-api)
BuildRequires:  mvn(org.osgi:osgi.core)

%description
Woodstox is a high-performance validating namespace-aware StAX-compliant
(JSR-173) Open Source XML-processor written in Java.
XML processor means that it handles both input (== parsing)
and output (== writing, serialization)), as well as supporting tasks
such as validation.


%package        javadoc
Summary:        API documentation for %{name}

%description    javadoc
This package contains the API documentation for %{name}.


%prep
%autosetup -p1 -n %{base_name}-%{name}-%{version}

%pom_remove_dep relaxngDatatype:relaxngDatatype
%pom_remove_dep net.java.dev.msv:
rm -rf src/main/java/com/ctc/wstx/msv

# Remove tests for msv and relaxng functionality
rm -rf src/test/java/wstxtest/msv src/test/java/wstxtest/vstream/TestRelaxNG.java src/test/java/stax2/vwstream/W3CSchemaWrite*Test.java \
  src/test/java/failing/{TestRelaxNG,TestW3CSchemaTypes,TestW3CSchemaComplexTypes,TestW3CDefaultValues}.java

# Unnecessary for RPM builds
%pom_remove_plugin :nexus-staging-maven-plugin

# we don't care about Java 9 modules (yet)
%pom_remove_plugin :moditect-maven-plugin

# replace felix-osgi-core with osgi-core
%pom_change_dep -r :org.osgi.core org.osgi:osgi.core

%mvn_alias ":{woodstox-core}" :@1-lgpl :@1-asl :wstx-asl :wstx-lgpl \
    org.codehaus.woodstox:@1 org.codehaus.woodstox:@1-asl \
    org.codehaus.woodstox:@1-lgpl org.codehaus.woodstox:wstx-lgpl \
    org.codehaus.woodstox:wstx-asl

%mvn_file : %{name}{,-asl,-lgpl}


%build
%mvn_build --xmvn-javadoc


%install
%mvn_install


%files -f .mfiles
%doc README.md
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE



%changelog
* Wed Oct 21 2020 daviddavid <daviddavid> 6.2.3-1.mga8
+ Revision: 1637713
- Update to version 6.2.3

* Fri Sep 04 2020 daviddavid <daviddavid> 6.2.1-1.mga8
+ Revision: 1621577
- Update to version 6.2.1
- javadoc generation  moved to  --xmvn-javadoc
- Rebuilt for JDK-11

* Sun Feb 16 2020 umeabot <umeabot> 6.0.1-2.mga8
+ Revision: 1536147
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 6.0.1-1.mga8
+ Revision: 1453383
- Update to version 6.0.1
- Port to newer OSGi API

* Sat Aug 24 2019 daviddavid <daviddavid> 5.2.1-1.mga8
+ Revision: 1431664
- Update to version 5.2.1

* Fri Sep 21 2018 umeabot <umeabot> 5.0.3-2.mga7
+ Revision: 1292017
- Mageia 7 Mass Rebuild

* Sat Sep 02 2017 daviddavid <daviddavid> 5.0.3-1.mga7
+ Revision: 1150914
- Update to upstream version 5.0.3 (sync with fc27)
- add BR mvn(org.apache:apache:pom:)
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 5.0.1-2.mga6
+ Revision: 978218
- First rebuild of the java stack
- sync package woodstox-core with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 4.2.0-8.mga5
+ Revision: 744416
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sat May 24 2014 dmorgan <dmorgan> 4.2.0-6.mga5
+ Revision: 625341
- New version

* Mon Dec 16 2013 dmorgan <dmorgan> 4.2.0-5.mga4
+ Revision: 557198
- Fix buildrequires
- Fix buildrequires

* Mon Oct 21 2013 umeabot <umeabot> 4.2.0-4.mga4
+ Revision: 541226
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 dmorgan <dmorgan> 4.2.0-3.mga4
+ Revision: 495356
- New version

* Thu Jan 17 2013 dmorgan <dmorgan> 4.1.2-8.mga3
+ Revision: 389051
- Remove glassfish-stax-api support

* Thu Jan 17 2013 dmorgan <dmorgan> 4.1.2-7.mga3
+ Revision: 389027
- Remove glassfish-stax-api support

* Thu Jan 17 2013 dmorgan <dmorgan> 4.1.2-6.mga3
+ Revision: 389025
- Remove glassfish-stax-api support

* Mon Jan 14 2013 umeabot <umeabot> 4.1.2-5.mga3
+ Revision: 385823
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jun 23 2012 dmorgan <dmorgan> 4.1.2-4.mga3
+ Revision: 262716
- Build with maven
+ gil <gil>
- build fix
  rebuilt with ant support
  added OSGi support

* Sun Dec 25 2011 dmorgan <dmorgan> 4.1.2-3.mga2
+ Revision: 187637
- imported package woodstox-core


* Tue Sep 13 2011 Jaromir Capik <jcapik@redhat.com> - 4.1.2-1
- Initial version
